/**************************************************************************************
 *                                                                                    *
 * This application contains code from OpenDivX and is released as a "Larger Work"    *
 * under that license. Consistant with that license, this application is released     *
 * under the GNU General Public License.                                              *
 *                                                                                    *
 * The OpenDivX license can be found at: http://www.projectmayo.com/opendivx/docs.php *
 * The GPL can be found at: http://www.gnu.org/copyleft/gpl.html                      *
 *                                                                                    *
 * Copyright (c) 2001 - Project Mayo                                                  *
 *                                                                                    *
 * Authors: Damien Chavarria <adrc at projectmayo.com>                                *
 *                                                                                    *
 **************************************************************************************/


#include "Codec.h"

/*
 * Functions
 *
 */

/*
 * Constructor : tries to open the stream
 *
 */

Codec::Codec(BITMAPINFOHEADER *bih)
{
	HRESULT h;

	this->hic = 0;

	if(bih) {
		
		if(bih->biCompression == 4) {
			
		    bih->biCompression = mmioFOURCC('D', 'I', 'V', 'X');
		}
			
		this->hic = ICOpen(mmioFOURCC('V', 'I', 'D', 'C'), 
						             bih->biCompression,
						             ICMODE_FASTDECOMPRESS);

		if(this->hic != 0) {

			ZeroMemory(&this->in_bih, sizeof(BITMAPINFO));
			ZeroMemory(&this->out_bih, sizeof(BITMAPINFO));

		    memcpy(&this->in_bih.bmiHeader, bih, sizeof(BITMAPINFOHEADER));
			
			out_bih.bmiHeader.biSize = sizeof(BITMAPINFOHEADER);

			h = ICDecompressGetFormat( this->hic, &this->in_bih, &this->out_bih ); 

			if(h == ICERR_OK) {

				h = ICDecompressQuery(this->hic, &this->in_bih, &this->out_bih);
			    
				this->out_bih.bmiHeader.biSizeImage = out_bih.bmiHeader.biWidth*out_bih.bmiHeader.biHeight*out_bih.bmiHeader.biBitCount/8;

				h = ICDecompressBegin(this->hic, &this->in_bih, &this->out_bih);  
			
				if(h != ICERR_OK) {
					MessageBox(NULL, "Can't Begin Decompression", "", MB_OK);
					this->hic = 0;
				}
			}
			else {

				MessageBox(NULL, "Codec not working!", "", MB_OK);
				this->hic = 0;
			}
		}
		else {

			MessageBox(NULL, "Can't find any appropriate Codec!", "", MB_OK);
			this->hic = 0;
		}
	}
	else {
		
		MessageBox(NULL, "Codec : wrong input parameters!", "Error", MB_OK);
	}
}

/* 
 * Destructor : Cleanup.
 *
 */

Codec::~Codec()
{

}

/*
 * Returns TRUE if codec is
 * ready to decode data.
 */

int Codec::IsOK()
{
	return (this->hic != 0);
}

/*
 * Decompress on frame
 *
 */

int Codec::Decompress(char *in, long in_size, char *out)
{
	HRESULT h;
	
	if(this->hic) {
		
		this->in_bih.bmiHeader.biSizeImage = in_size;

		if(in_size == 0) {
		
		h = ICDecompress(this->hic, ICDECOMPRESS_NULLFRAME,
						 &this->in_bih.bmiHeader, (void *) in,
						 &this->out_bih.bmiHeader, (void *) out);

		}
		else {

		h = ICDecompress(this->hic, ICDECOMPRESS_NOTKEYFRAME,
						 &this->in_bih.bmiHeader, (void *) in,
						 &this->out_bih.bmiHeader, (void *) out);
		}
	}

	return 1;
}

/*
 * Drops one frame.
 *
 */

int Codec::Drop(char *in, long in_size, char *out) 
{
	if(this->hic) {
	
		this->in_bih.bmiHeader.biSizeImage = in_size;

		ICDecompress(this->hic, ICDECOMPRESS_HURRYUP,
					 &this->in_bih.bmiHeader, (void *) in,
					 &this->out_bih.bmiHeader, (void *) out);
	}

	return 1;
}

/*
 * Closes the decoder.
 *
 */

int Codec::Close()
{
	if(this->hic)
	{
		ICDecompressEnd(this->hic);
		ICClose(this->hic);
	}

	return 1;
}
